/*
  This file is part of RawTherapee.

  Copyright (c) 2016-2017 TooWaBoo
  Requires RT 5.0 (Gtk+ >= 3.20)

  RawTherapee is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  RawTherapee is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with RawTherapee.  If not, see <https://www.gnu.org/licenses/>.
*/


/*****************************************/
/**/ @import "TooWaBlue.css"; /**/
/*****************************************/

/*** Change me *** rgb(red,green,blue) *** allowed values from 0 to 255 for each color ***/

@define-color accent-color rgb(65,65,65);              /*** Active color for Lists, Menu, Borders ... * Default: rgb(33,82,145) ***/
@define-color text-hl-color rgb(200,200,200);           /*** Active text color * Default: rgb(200,200,200) ***/

@define-color bg-highlighted-text-color rgb(33,82,150); /*** Highlighted text color background* Default: rgb(33,82,145) ***/
@define-color highlighted-text-color rgb(200,200,200);  /*** Highlighted text color * Default: rgb(200,200,200) ***/

@define-color bg-image rgb(58,58,58);                   /*** Image area & File Browser background * Default: rgb(58,58,58) ***/

@define-color accent-color2 rgb(33,82,150);             /*** Scale, Progressbar, Scrollbar, Tabs * Default: rgb(33,82,145) ***/
@define-color accent-color4 rgb(98,98,98);              /*** Slider knob * Default: rgb(98,98,98) ***/

@define-color accent-color3 rgb(30,30,30);             /*** Selected thumbnail background color * Default: rgb(33,82,145) ***/
@define-color text-hl-color3 rgb(200,200,200);          /*** Selected thumbnail text color * Default: rgb(200,200,200) ***/

/*** Change me end *****************************************************************************/

@define-color bg-light-grey rgb(75,75,75);
@define-color bg-grey rgb(58,58,58);
@define-color bg-dark-grey rgb(30,30,30);

@define-color bg-button-hover rgba(0,0,0,.3);
@define-color bg-button-active rgba(0,0,0,.7);

@define-color winHeaderbar rgb(50,50,50);
@define-color winTitle rgb(190,190,190);

@define-color bg-tooltip rgb(170,170,170);
@define-color border-tooltip rgb(36,36,36);
@define-color text-tooltip rgb(36,36,36);
/***********************************************/
@define-color text-color rgb(176,176,176);
@define-color text-tbEntry rgb(192,192,192);
@define-color border-color rgba(255,255,255,.30);
@define-color bg-list-hover rgb(50,50,50);
@define-color bg-scale-entry rgba(0,0,0,.14);
@define-color bg-button-border rgba(0,0,0,.60);
@define-color bg-entry-border rgba(0,0,0,.40);
@define-color view-grid-border rgba(255,255,255,0.15);
@define-color headline-big rgb(187,187,187);
@define-color headline-hl rgb(215,215,215);
@define-color headline-frame rgb(210,210,210);
/*** New Color Variable v2.53 ************************************************************************/
@define-color fg-disabled rgb(128,128,128);
@define-color bg-tb-spinbutton shade(@bg-grey, 1.35);
/***********************************************************************************************/
