/*
  This file is part of RawTherapee.

  Copyright (c) 2016-2017 TooWaBoo
  Requires RT 5.0 (Gtk+ >= 3.20)

  RawTherapee is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  RawTherapee is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with RawTherapee.  If not, see <https://www.gnu.org/licenses/>.
*/


/*****************************************/
/**/ @import "TooWaBlue.css"; /**/
/*****************************************/

/*** Change me *** rgb(red,green,blue) *** allowed values from 0 to 255 for each color ***/

@define-color accent-color rgb(110,110,110);              /*** Active color for Lists, Menu, Borders ... * Default: rgb(35,99,166) ***/
@define-color text-hl-color rgb(255,255,255);           /*** Active text color * Default: rgb(210,210,210) ***/

@define-color bg-highlighted-text-color rgb(49,132,220); /*** Highlighted text color background* Default: rgb(35,99,166) ***/
@define-color highlighted-text-color rgb(255,255,255);  /*** Highlighted text color * Default: rgb(210,210,210) ***/

@define-color bg-image rgb(120,120,120);                   /*** Image area & File Browser background * Default: rgb(70,70,70) ***/

@define-color accent-color2 rgb(175,175,175);             /*** Scale, Progressbar, Scrollbar, Tabs * Default: rgb(35,99,166) ***/
@define-color accent-color4 rgb(155,155,155);           /*** Slider knob * Default: rgb(115,115,115) ***/

@define-color accent-color3 rgb(85,85,85);             /*** Selected thumbnail background color * Default: rgb(35,99,166) ***/
@define-color text-hl-color3 rgb(230,230,230);          /*** Selected thumbnail text color * Default: rgb(210,210,210) ***/

/*** Change me end *****************************************************************************/

@define-color bg-light-grey rgb(135,135,135);
@define-color bg-grey rgb(120,120,120);
@define-color bg-dark-grey rgb(90,90,90);

@define-color bg-button-hover rgba(40,40,40,.16);
@define-color bg-button-active rgba(40,40,40,.4);

@define-color winHeaderbar rgb(75,75,75);
@define-color winTitle rgb(210,210,210);

@define-color bg-tooltip rgb(210,210,210);
@define-color border-tooltip rgb(50,50,50);
@define-color text-tooltip rgb(50,50,50);
/***********************************************/
@define-color text-color rgb(220,220,220);
@define-color text-tbEntry rgb(245,245,245);
@define-color border-color rgba(255,255,255,.35);
@define-color bg-list-hover rgb(95,95,95);
@define-color bg-scale-entry rgba(0,0,0,.14);
@define-color bg-button-border rgba(0,0,0,.45);
@define-color bg-entry-border rgba(0,0,0,.40);
@define-color view-grid-border rgba(255,255,255,0.25);
@define-color headline-big rgb(210,210,210);
@define-color headline-hl rgb(255,255,255);
@define-color headline-frame rgb(245,245,245);
/*** New Color Variable v2.53 ************************************************************************/
@define-color fg-disabled rgb(180,180,180);
@define-color bg-tb-spinbutton shade(@bg-grey, 1.20);
/***********************************************************************************************/
